==> SexyMap-v8.3.0.zip: SexyMap/localization/frFR.lua <==

if GetLocale() ~= "frFR" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "Arriere-plan"
L["2. Border"] = "Bordure"
L["3. Artwork"] = "Apparence Graphique"
L["4. Overlay"] = "Overlay (superposition)"
L["5. Highlight"] = "Mettre en surbrillance"
L["Add Blend (additive)"] = "Ajouter Mélange (additif)"
L["Addon Buttons"] = "Boutons d'addons"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Un profil global existe déja. Vos réglages seront activer avec ce profil et votre interface sera recharge, êtes-vous sur de vouloir faire ceci?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Autoriser SexyMap à s'occupé des deplacements des boutons attaches a la mini-carte. Desactivez cette option si vous voulez utiliser un autre addon pour positionner vos boutons de mini-carte." -- Needs review
L["Alpha Key (1-bit alpha)"] = "Clef Alpha (alpha d'un bit)"
L["Always"] = "Toujours"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Etes-vous sur que vous voulez revenir a un profil unique par personnage? Ceci rechargera également votre interface utilisateur."
L["Armored Man"] = "Sante de L'armure du joueur"
L["A static amount to rotate the texture by."] = "Un montant fixe pour faire tourner la texture."
L["Auto Zoom-Out Delay"] = "Delai de retour du Zoom Automatique"
L["Backdrop Color"] = "Couleur de l'arriere-plan" -- Needs review
L["Backdrop Insets"] = "Parametre Interieur de l'arriere-plan" -- Needs review
L["Background Color"] = "Couleurs de l'arriere-plan "
L["Background/edge"] = "Arriere-plan/Bord" -- Needs review
L["Background Texture"] = "Texture de l arriere-plan"
L["Blend Mode"] = "Mode mélange" -- Needs review
L["Blend (normal)"] = "Mélange (normale)" -- Needs review
L["Border Color"] = "Couleur de la bordure"
L["Border Edge Size"] = "Taille du Bord de la Bordure"
L["Borders"] = "Bordures"
L["Border Texture"] = "Texture de la Bordure"
L["Boss Frames"] = "Santé des Boss" -- Needs review
L["Buttons"] = "Boutons"
L["Calendar"] = "Calendrier"
L["Capture Bars"] = "Barre de Capture"
L["Challenge Mode Button (When Available)"] = "Bouton de Challenge Mode (quand applicable). " -- Needs review
L["Circle"] = "Cercle"
L["Clamp to screen"] = "Fixer a l'ecran"
L["Clear & start over"] = "Effacer & Recommencer:"
L["Clear the current borders and start fresh"] = "Effacer la bordure Actuelle et commencer le rafraichissement"
L["Clock"] = "Horloge"
L["Coordinates"] = "Coordonnées" -- Needs review
L["Copy a Profile"] = "Copier un Profil"
L["Copying this profile will reload your UI, are you sure?"] = "Copier ce profil effecturas un rechargement de votre interface, Etes-vous sur de vouloir faire cela maintenant?"
L["Create a new border"] = "Créer une nouvelle bordure" -- Needs review
L["Current Borders"] = "Bordures Actuelle"
L["Default Presets"] = "Préréglage par Defaut"
L["Delete"] = "Supprimer"
L["Delete a Profile"] = "Effacer un Profil"
L["Diamond"] = "Diamant"
L["Disable (opaque)"] = "Désactiver (opaque)" -- Needs review
L["Disable Rotation"] = "Desactiver la Rotation"
L["Disabling the movers will make them reset next time you relog, are you sure?"] = "Désactiver le déplacment des cadres réinitialiseras les réglages au prochain redémarrage du jeu, Etes-vous vraiment sur ?"
L["Drag Radius"] = "Rayon des boutons autour de la minimap"
L["Dungeon Difficulty Indicator (When Available)"] = "Indicateur de la difficulté du donjon (Quand disponible)"
L["Dynamic Buttons"] = "Bouttons Dynamiques"
L["Enable"] = "Activer"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Mettre en place un arriere-plan et contour pour la mini-carte.  Si vous faisez ça il devient plutot facile de specifié les bordures carrées"
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Activer une Mini Carte en Relief(mini hudmap). Ceci est tres utile pour la collecte de ressources (farm), mais pour des raisons techniques, la Carte en Relief et la Minicarte officiel du jeu ne peut pas etre affichee en meme temps. L'affichage de la Mini Carte en Relief desactiveras la Minicarte officiel du jeu."
L["Enable Coordinates"] = "Activer les coordonnées" -- Needs review
L["Enable Hudmap"] = "Activer Carte en Relief (hudmap)"
L["Enable Minimap Fader"] = "Activer Transparence de la Minimap"
L["Enable Movers"] = "Activer Déplacement"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Entrer un Nom pour Creer une nouvelle Bordure. Ce nom peux vous servir a identifier cette bordure." -- Needs review
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Entrer le Chemin complet de la Texture pour l'utiliser. il est recommander d'utiliser de préférence ceci |cffff6600TexBrowser|r pour trouver la texture que vous voulez."
L["Entry Options"] = "Parametres"
L["Faded Circle (Large)"] = "Cercle Transparent (Grand)"
L["Faded Circle (Small)"] = "Cercle Transparent (Petit)"
L["Faded Square"] = "Carré Transparent"
L["Fader"] = "assombrir"
L["Font"] = "Police d'écriture"
L["Font Color"] = "Couleur de la police"
L["Font Size"] = "Taille de la police"
L["Force a square texture. Fixed distortion on square textures."] = "Forcer une texture carré. Répare la déformation des textures carré."
L["Garrison Button (When Available)"] = "Bouton de Garnison (Quand disponible)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicateur de difficulté des Dungeons en guilde (Quand disponible)"
L["Heart"] = "Coeur"
L["Height"] = "Hauteur"
L["Hexagon"] = "Hexagone"
L["Hide default border"] = "Cacher la bordure par defaut"
L["Hide the default border on the minimap."] = "Cacher la bordure par defaut sur la Mini-carte." -- Needs review
L["Horizontal Nudge"] = "Pouce Horizontale (alerte)" -- Needs review
L["Horizontal Position"] = "Position Horizontale"
L["Hover Opacity"] = "Tranparence au Survol"
L["HUD Color"] = "Couleurs de la Carte en Relief (hudmap)"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Si vous zoomer sur la carte, cet fonction permet de faire un Retour du Zoom automatique apres un certains temps(en secondes). Mettre la Valeur sur 0 pour désactiver cette fonction."
L["Keybinding"] = "Raccourci clavier"
L["Layer"] = "Couche"
L["Let SexyMap control button visibility"] = "Laisser Sexymap gérer la visibilité des Boutons"
L["Let SexyMap handle button dragging"] = "Laisser Sexymap gérer le placement des boutons"
L["Lock Button Dragging"] = "Verrouiller le déplacement des boutons"
L["Lock Minimap"] = "Verouiller la Minimap"
L["Lock Movers"] = "Verrouiller les Déplacement"
L["Map Button"] = "Bouton de la Carte"
L["Minimap shape"] = "Forme de la Mini-carte"
L["Mod Blend (modulative)"] = "Mod Blend (modulation)"
L["Movers"] = "Déplacement des Cadres"
L["Movers Warning"] = "ATTENTION: Cette fonction n'est pas officielement supportée, Certains problêmes apparaissent quand cette fonction est active. Comme la perte du systeme de suivi des quetes, La Barre des Boss qui sautille. Les Cadres Blizzard comme le suivi des quetes et de la sante des Boss ne sont pas conçus pour être deplacer, je vous suggerez donc d'utiliser des addons qui remplacent ces cadres comme par exemple PitBull, shadowed unit frames, perle, ou autres..." -- Needs review
L["Name"] = "Nom"
L["Never"] = "Jamais"
L["New Mail Indicator (When Available)"] = "Indiquateur des messages (Quand Disponible)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Aucun profil global existe. Votre profil actuel sera copie et utilisé comme Profil Global, êtes-vous sur de votre choix? Ceci rechargera également votre interface utilisateur."
L["Normal Opacity"] = "Transparence Normal" -- Needs review
L["Objectives Tracker"] = "Suivi des objetives" -- Needs review
L["Octagon"] = "Octogone"
L["On Hover"] = "au Survol"
L["Opacity"] = "Transparence"
L["Open TexBrowser"] = "Ouvrir TexBrowser"
L["Ping"] = "Ping(Latence)"
L["Preset"] = "Prereglage"
L["Prevent the minimap from being moved off the screen"] = "Eviter les mouvement de la minimap en dehors de l'écran" -- Needs review
L["Profiles"] = "Profils"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Voir le status pour la queue (PvP/LFG)" -- Needs review
L["Quickly change the look of your minimap by using a minimap preset."] = "Changer rapidement d'apparence pour votre mini-carte en utilisant un préréglage prédéfini."
L["Really delete this border?"] = "Etes vous sur de vouloir effacer cette Bordure?" -- Needs review
L["Really delete this preset? This can't be undone."] = "Etes vous sur de vouloir effacer ce Prereglage? Il n'est pas possible de reclaimer un prereglage effacé. " -- Needs review
L["Really delete this profile?"] = "Voulez-vous vraiment effacer ce profil?"
L["(Requires button visibility control in the Buttons menu)"] = "(Nécessite que Sexymap controle la visibilité des Boutons)"
L["Reset Current Profile"] = "Réinitialiser le profil actuel"
L["Resetting this profile will reload your UI, are you sure?"] = "Réinitialiser ce profil éffecturas un rechargement de votre interface, Etes-vous sur de vouloir faire cela maintenant?"
L["Right Click Configure"] = "Clic Droit pour Configurer"
L["Right clicking the map will open the SexyMap options"] = "Un Clic Droit sur la Carte de Sexymap ouvriras les options"
L["Rotation Speed (seconds)"] = "Vitesse de Rotation (secondes)" -- Needs review
L["Rounded - Bottom"] = "Arrondi - inférieur"
L["Rounded - Bottom Left"] = "Arrondi - inférieur Gauche"
L["Rounded - Bottom Right"] = "Arrondi - inférieur Droite"
L["Rounded - Left"] = "Arrondi - Gauche"
L["Rounded - Right"] = "Arrondi - Droite"
L["Rounded - Top"] = "Arrondi - Supérieur"
L["Rounded - Top Left"] = "Arrondi - Supérieur Gauche"
L["Rounded - Top Right"] = "Arrondi - Supérieur Droite"
L["Route 66"] = "Route 66"
L["Save current settings as preset..."] = "Sauvegarder la configuration actuels comme prereglage..." -- Needs review
L["Scale"] = "Taille"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Sélectionner le Préréglage pour Charger les parametres. (Ceci effaceras tous les reglages actuels de vos bordures.)"
L["Select preset to load"] = "Charger Préréglage prédéfini\009"
L["SharedMedia Border"] = "Bordure du SharedMedia"
L["SharedMedia Texture"] = "SharedMedia Texture"
L["Show inside chat"] = "A l'intérieur du Chat"
L["Show North Tag"] = "Afficher le Nord sur votre MiniCarte (Boussole)"
L["Show on minimap"] = "Afficher sur la Minimap"
L["Show %s:"] = "Voir %s:"
L["Show who pinged"] = "Voir le Ping (latence)"
L["Snowflake"] = "Flocon de neige"
L["Spice up your minimap with some sexy options."] = "Pimentez votre minicarte avec quelques options très sexy." -- Needs review
L["Square"] = "Carré"
L["Standard Buttons"] = "Bouttons Standard"
L["Static Rotation"] = "Rotation statique"
L["TexBrowser Not Installed"] = "TexBrowser n'est pas Installé" -- Needs review
L["Text Color"] = "Couleurs du Texte"
L["Texture"] = "Texture"
L["Texture Options"] = "Options Textures"
L["Texture Path"] = "Chemin de la Texture"
L["Texture Tint"] = "Teinte de la Texture"
L["Text Width"] = "Largeur du Texte"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "La Carte en Relief (HudMap) supporte beaucoup d'addons. Si vous avez l'un des addons installés ci-dessous, ils seront affichés sur la Carte en Relief (HudMap)."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "Temps nécéssaire (en secondes) pour faire une rotation complete. Si régler sur 0, la rotation seras désactivé."
L["This will wipe out any current settings!"] = "Cette opération éffaceras tous les paramètres actuels!"
L["Tile Background"] = "Arrière Plan (tuile)"
L["Tile Size"] = "Taille (tuile)"
L["Toggle HudMap On/Off"] = "Carte en Relief (hudmap) On/Off"
L["Tracking Button"] = "Bouton de Suivi"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Désactiver si vous voulez qu'un autre Mod prendre en charge les bouttons de minimap."
L["Use Global Profile"] = "Utiliser un Profil Global"
L["User-Submitted Presets"] = "Préréglages Défini par des autres Utilisateurs."
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Utiliser un Profil Global, si vous activer cette options l'apparence sera la meme pour tous vos personnages. Sinon utiliser un Profil Unique pour chacun de vos personnages."
L["Vehicle Seat"] = "Boutton Véhicule (sortir)"
L["Vertical Nudge"] = "Wizz Verticale(alerte)"
L["Vertical Position"] = "Position Verticale"
L["Visibility"] = "Visibilité" -- Needs review
L["Width"] = "Largeur"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Vous pouvez spécifier un arrière-plan et une bordure pour la mini-carte comme un cadre.  Cela est utile quand vous voulez créer des arrière-plans de carré statique pour votre mini-carte."
L["Zone Text"] = "Zone de Texte"
L["Zoom In Button"] = "Boutton Zoom Interieur"
L["Zoom Out Button"] = "Boutton Zoom Exterieur"

--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."

==> SexyMap-v9.2.15.zip: SexyMap/localization/frFR.lua <==

if GetLocale() ~= "frFR" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "Arriere-plan"
L["2. Border"] = "Bordure"
L["3. Artwork"] = "Apparence Graphique"
L["4. Overlay"] = "Overlay (superposition)"
L["5. Highlight"] = "Mettre en surbrillance"
L["Add Blend (additive)"] = "Ajouter Mélange (additif)"
L["Addon Buttons"] = "Boutons d'addons"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Un profil global existe déja. Vos réglages seront activer avec ce profil et votre interface sera recharge, êtes-vous sur de vouloir faire ceci?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Autoriser SexyMap à s'occupé des deplacements des boutons attaches a la mini-carte. Desactivez cette option si vous voulez utiliser un autre addon pour positionner vos boutons de mini-carte." -- Needs review
L["Alpha Key (1-bit alpha)"] = "Clef Alpha (alpha d'un bit)"
L["Always"] = "Toujours"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Etes-vous sur que vous voulez revenir a un profil unique par personnage? Ceci rechargera également votre interface utilisateur."
L["Armored Man"] = "Sante de L'armure du joueur"
L["A static amount to rotate the texture by."] = "Un montant fixe pour faire tourner la texture."
L["Auto Zoom-Out Delay"] = "Delai de retour du Zoom Automatique"
L["Backdrop Color"] = "Couleur de l'arriere-plan" -- Needs review
L["Backdrop Insets"] = "Parametre Interieur de l'arriere-plan" -- Needs review
L["Background Color"] = "Couleurs de l'arriere-plan "
L["Background/edge"] = "Arriere-plan/Bord" -- Needs review
L["Background Texture"] = "Texture de l arriere-plan"
L["Blend Mode"] = "Mode mélange" -- Needs review
L["Blend (normal)"] = "Mélange (normale)" -- Needs review
L["Border Color"] = "Couleur de la bordure"
L["Border Edge Size"] = "Taille du Bord de la Bordure"
L["Borders"] = "Bordures"
L["Border Texture"] = "Texture de la Bordure"
L["Boss Frames"] = "Santé des Boss" -- Needs review
L["Buttons"] = "Boutons"
L["Calendar"] = "Calendrier"
L["Challenge Mode Button (When Available)"] = "Bouton de Challenge Mode (quand applicable). " -- Needs review
L["Circle"] = "Cercle"
L["Clamp to screen"] = "Fixer a l'ecran"
L["Clear & start over"] = "Effacer & Recommencer:"
L["Clear the current borders and start fresh"] = "Effacer la bordure Actuelle et commencer le rafraichissement"
L["Clock"] = "Horloge"
L["Coordinates"] = "Coordonnées" -- Needs review
L["Copy a Profile"] = "Copier un Profil"
L["Copying this profile will reload your UI, are you sure?"] = "Copier ce profil effecturas un rechargement de votre interface, Etes-vous sur de vouloir faire cela maintenant?"
L["Create a new border"] = "Créer une nouvelle bordure" -- Needs review
L["Current Borders"] = "Bordures Actuelle"
L["Default Presets"] = "Préréglage par Defaut"
L["Delete"] = "Supprimer"
L["Delete a Profile"] = "Effacer un Profil"
L["Diamond"] = "Diamant"
L["Disable (opaque)"] = "Désactiver (opaque)" -- Needs review
L["Disable Rotation"] = "Desactiver la Rotation"
L["Drag Radius"] = "Rayon des boutons autour de la minimap"
L["Dungeon Difficulty Indicator (When Available)"] = "Indicateur de la difficulté du donjon (Quand disponible)"
L["Dynamic Buttons"] = "Bouttons Dynamiques"
L["Enable"] = "Activer"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Mettre en place un arriere-plan et contour pour la mini-carte.  Si vous faisez ça il devient plutot facile de specifié les bordures carrées"
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Activer une Mini Carte en Relief(mini hudmap). Ceci est tres utile pour la collecte de ressources (farm), mais pour des raisons techniques, la Carte en Relief et la Minicarte officiel du jeu ne peut pas etre affichee en meme temps. L'affichage de la Mini Carte en Relief desactiveras la Minicarte officiel du jeu."
L["Enable Coordinates"] = "Activer les coordonnées" -- Needs review
L["Enable Hudmap"] = "Activer Carte en Relief (hudmap)"
L["Enable Minimap Fader"] = "Activer Transparence de la Minimap"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Entrer un Nom pour Creer une nouvelle Bordure. Ce nom peux vous servir a identifier cette bordure." -- Needs review
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Entrer le Chemin complet de la Texture pour l'utiliser. il est recommander d'utiliser de préférence ceci |cffff6600TexBrowser|r pour trouver la texture que vous voulez."
L["Entry Options"] = "Parametres"
L["Faded Circle (Large)"] = "Cercle Transparent (Grand)"
L["Faded Circle (Small)"] = "Cercle Transparent (Petit)"
L["Faded Square"] = "Carré Transparent"
L["Fader"] = "assombrir"
L["Font"] = "Police d'écriture"
L["Font Color"] = "Couleur de la police"
L["Font Size"] = "Taille de la police"
L["Force a square texture. Fixed distortion on square textures."] = "Forcer une texture carré. Répare la déformation des textures carré."
L["Garrison Button (When Available)"] = "Bouton de Garnison (Quand disponible)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicateur de difficulté des Dungeons en guilde (Quand disponible)"
L["Heart"] = "Coeur"
L["Height"] = "Hauteur"
L["Hexagon"] = "Hexagone"
L["Hide default border"] = "Cacher la bordure par defaut"
L["Hide the default border on the minimap."] = "Cacher la bordure par defaut sur la Mini-carte." -- Needs review
L["Horizontal Nudge"] = "Pouce Horizontale (alerte)" -- Needs review
L["Horizontal Position"] = "Position Horizontale"
L["Hover Opacity"] = "Tranparence au Survol"
L["HUD Color"] = "Couleurs de la Carte en Relief (hudmap)"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Si vous zoomer sur la carte, cet fonction permet de faire un Retour du Zoom automatique apres un certains temps(en secondes). Mettre la Valeur sur 0 pour désactiver cette fonction."
L["Keybinding"] = "Raccourci clavier"
L["Layer"] = "Couche"
L["Let SexyMap control button visibility"] = "Laisser Sexymap gérer la visibilité des Boutons"
L["Let SexyMap handle button dragging"] = "Laisser Sexymap gérer le placement des boutons"
L["Lock Button Dragging"] = "Verrouiller le déplacement des boutons"
L["Lock Minimap"] = "Verouiller la Minimap"
L["Map Button"] = "Bouton de la Carte"
L["Minimap shape"] = "Forme de la Mini-carte"
L["Mod Blend (modulative)"] = "Mod Blend (modulation)"
L["Movers"] = "Déplacement des Cadres"
L["Name"] = "Nom"
L["Never"] = "Jamais"
L["New Mail Indicator (When Available)"] = "Indiquateur des messages (Quand Disponible)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Aucun profil global existe. Votre profil actuel sera copie et utilisé comme Profil Global, êtes-vous sur de votre choix? Ceci rechargera également votre interface utilisateur."
L["Normal Opacity"] = "Transparence Normal" -- Needs review
L["Objectives Tracker"] = "Suivi des objetives" -- Needs review
L["Octagon"] = "Octogone"
L["On Hover"] = "au Survol"
L["Opacity"] = "Transparence"
L["Open TexBrowser"] = "Ouvrir TexBrowser"
L["Ping"] = "Ping(Latence)"
L["Preset"] = "Prereglage"
L["Prevent the minimap from being moved off the screen"] = "Eviter les mouvement de la minimap en dehors de l'écran" -- Needs review
L["Profiles"] = "Profils"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Voir le status pour la queue (PvP/LFG)" -- Needs review
L["Quickly change the look of your minimap by using a minimap preset."] = "Changer rapidement d'apparence pour votre mini-carte en utilisant un préréglage prédéfini."
L["Really delete this border?"] = "Etes vous sur de vouloir effacer cette Bordure?" -- Needs review
L["Really delete this preset? This can't be undone."] = "Etes vous sur de vouloir effacer ce Prereglage? Il n'est pas possible de reclaimer un prereglage effacé. " -- Needs review
L["Really delete this profile?"] = "Voulez-vous vraiment effacer ce profil?"
L["(Requires button visibility control in the Buttons menu)"] = "(Nécessite que Sexymap controle la visibilité des Boutons)"
L["Reset Current Profile"] = "Réinitialiser le profil actuel"
L["Resetting this profile will reload your UI, are you sure?"] = "Réinitialiser ce profil éffecturas un rechargement de votre interface, Etes-vous sur de vouloir faire cela maintenant?"
L["Right Click Configure"] = "Clic Droit pour Configurer"
L["Right clicking the map will open the SexyMap options"] = "Un Clic Droit sur la Carte de Sexymap ouvriras les options"
L["Rotation Speed (seconds)"] = "Vitesse de Rotation (secondes)" -- Needs review
L["Rounded - Bottom"] = "Arrondi - inférieur"
L["Rounded - Bottom Left"] = "Arrondi - inférieur Gauche"
L["Rounded - Bottom Right"] = "Arrondi - inférieur Droite"
L["Rounded - Left"] = "Arrondi - Gauche"
L["Rounded - Right"] = "Arrondi - Droite"
L["Rounded - Top"] = "Arrondi - Supérieur"
L["Rounded - Top Left"] = "Arrondi - Supérieur Gauche"
L["Rounded - Top Right"] = "Arrondi - Supérieur Droite"
L["Route 66"] = "Route 66"
L["Save current settings as preset..."] = "Sauvegarder la configuration actuels comme prereglage..." -- Needs review
L["Scale"] = "Taille"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Sélectionner le Préréglage pour Charger les parametres. (Ceci effaceras tous les reglages actuels de vos bordures.)"
L["Select preset to load"] = "Charger Préréglage prédéfini\009"
L["SharedMedia Border"] = "Bordure du SharedMedia"
L["SharedMedia Texture"] = "SharedMedia Texture"
L["Show inside chat"] = "A l'intérieur du Chat"
L["Show North Tag"] = "Afficher le Nord sur votre MiniCarte (Boussole)"
L["Show on minimap"] = "Afficher sur la Minimap"
L["Show %s:"] = "Voir %s:"
L["Show who pinged"] = "Voir le Ping (latence)"
L["Snowflake"] = "Flocon de neige"
L["Spice up your minimap with some sexy options."] = "Pimentez votre minicarte avec quelques options très sexy." -- Needs review
L["Square"] = "Carré"
L["Standard Buttons"] = "Bouttons Standard"
L["Static Rotation"] = "Rotation statique"
L["TexBrowser Not Installed"] = "TexBrowser n'est pas Installé" -- Needs review
L["Text Color"] = "Couleurs du Texte"
L["Texture"] = "Texture"
L["Texture Options"] = "Options Textures"
L["Texture Path"] = "Chemin de la Texture"
L["Texture Tint"] = "Teinte de la Texture"
L["Text Width"] = "Largeur du Texte"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "La Carte en Relief (HudMap) supporte beaucoup d'addons. Si vous avez l'un des addons installés ci-dessous, ils seront affichés sur la Carte en Relief (HudMap)."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "Temps nécéssaire (en secondes) pour faire une rotation complete. Si régler sur 0, la rotation seras désactivé."
L["This will wipe out any current settings!"] = "Cette opération éffaceras tous les paramètres actuels!"
L["Tile Background"] = "Arrière Plan (tuile)"
L["Tile Size"] = "Taille (tuile)"
L["Toggle HudMap On/Off"] = "Carte en Relief (hudmap) On/Off"
L["Tracking Button"] = "Bouton de Suivi"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Désactiver si vous voulez qu'un autre Mod prendre en charge les bouttons de minimap."
L["Use Global Profile"] = "Utiliser un Profil Global"
L["User-Submitted Presets"] = "Préréglages Défini par des autres Utilisateurs."
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Utiliser un Profil Global, si vous activer cette options l'apparence sera la meme pour tous vos personnages. Sinon utiliser un Profil Unique pour chacun de vos personnages."
L["Vehicle Seat"] = "Boutton Véhicule (sortir)"
L["Vertical Nudge"] = "Wizz Verticale(alerte)"
L["Vertical Position"] = "Position Verticale"
L["Visibility"] = "Visibilité" -- Needs review
L["Width"] = "Largeur"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Vous pouvez spécifier un arrière-plan et une bordure pour la mini-carte comme un cadre.  Cela est utile quand vous voulez créer des arrière-plans de carré statique pour votre mini-carte."
L["Zone Text"] = "Zone de Texte"
L["Zoom In Button"] = "Boutton Zoom Interieur"
L["Zoom Out Button"] = "Boutton Zoom Exterieur"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP Barre de Capture"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"
